first_unmet_call

Function first_unmet_call 

pub(crate) fn first_unmet_call(
    tracker: &ExpectedCallTracker,
    succeeded: bool,
) -> Option<String>
Returns the failure message for the smallest unmet call expectation, if any.

Expectations are ordered by address, calldata and call scheme. succeeded is false for both reverts and halts.