handle_expect_emit

Function handle_expect_emit 

pub(crate) fn handle_expect_emit<FEN: FoundryEvmNetwork>(
    state: &mut Cheatcodes<FEN>,
    log: &Log,
    interpreter: Option<&mut Interpreter>,
) -> Option<&'static str>
Applies an expectEmit failure for log by reverting the current call, when an interpreter is available.

Without an interpreter, the failure reason is returned to the caller instead.