observe_create

Function observe_create 

pub(crate) fn observe_create(
    expected_creates: &mut Vec<ExpectedCreate>,
    deployer: Address,
    create_scheme: impl Fn() -> CreateScheme,
    bytecode: &Bytes,
)
Removes the first create expectation matched by a completed create.

create_scheme is only called for expectations with a matching deployer.