ExpectedCallsForTarget

Type Alias ExpectedCallsForTarget 

pub type ExpectedCallsForTarget = HashMap<(Bytes, Option<CallScheme>), (ExpectedCallData, u64)>;
Tracks calldata, scheme and count expectations for one target.

Aliased Type

pub struct ExpectedCallsForTarget { /* private fields */ }

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 40 bytes